<center>![Korapay Client Banner](assets/korapay-logo.svg)</center>
<center><b>A developer-friendly python client SDK for <a href="https://www.korahq.com/" target="_blank">Korapay</a></b></center>
<hr />

Documentation: [https://gray-adeyi.github.io/korapay_client/](https://gray-adeyi.github.io/korapay_client/)

Source Code: [https://github.com/gray-adeyi/korapay_client](https://github.com/gray-adeyi/korapay_client)

## Features

* **Type hints**: `korapay_client` supports type hints out of the box for a smooth developer experience.
* **Easy imports**: every feature you need i.e. client classes, enums,models, e.t.c. can be imported directly from `korapay_client`.
* **Async support**: `korapay_client` provides `AsyncKorapayClient` for the `async/await` paradigm,
  suitable for use in your [FastAPI](https://fastapi.tiangolo.com/) based projects.

## Requirements

`korapay_client` requires `python >=3.10`

## Installation

```bash
pip install korapay-client
```

## License

This project is licensed under the terms of the MIT license.

## Contributing

You might encounter bugs while using this project or have feature enhancements you'd like to 
share with the project. Please follow the [CONTRIBUTING.md](https://github.com/gray-adeyi/korapay_client) 
on how to contribute to this project.

## Questions

You may have questions about this project. Please check the FAQs tab to see if your question
has been answered already, if not create an issue about it in the project's Github repository.

## Sponsorship

Every little donation goes a long way. You can also give this project a star in its
Github repository it helps ♥️

[Buy me a coffee](https://www.buymeacoffee.com/jigani){ .md-button }